Class: RailsDevelopmentBoost::Async::Reactor::Linux

Inherits:
Base
  • Object
show all
Defined in:
lib/rails_development_boost/async/reactor.rb

Overview

Errors, comments and other gotchas taken from Listen gem (github.com/guard/listen)

Constant Summary collapse

TARGET_OS_REGEX =
/linux/i
GEM_NAME =
'rb-inotify'
GEM_VERSION =
'>= 0.8.8'
EVENTS =
[:recursive, :attrib, :create, :delete, :move, :close_write]
INOTIFY_LIMIT_MESSAGE =

The message to show when the limit of inotify watchers is not enough

<<-EOS.gsub(/^\s*/, '')
  Listen error: unable to monitor directories for changes.

  Please head to https://github.com/guard/listen/wiki/Increasing-the-amount-of-inotify-watchers
  for information on how to solve this issue.
EOS

Method Summary

Methods inherited from Base

#alive_and_watching?, #initialize, #start!, #stop, usable?, #watch

Constructor Details

This class inherits a constructor from RailsDevelopmentBoost::Async::Reactor::Base